package org.greenstone.gatherer.gui;


import java.awt.*;
import java.io.*;
import javax.swing.*;
import javax.swing.table.DefaultTableCellRenderer;
import org.greenstone.gatherer.Configuration;
import org.greenstone.gatherer.metadata.MetadataElement;
import org.greenstone.gatherer.metadata.MetadataTools;
import org.greenstone.gatherer.metadata.MetadataValueTableModel;
import org.greenstone.gatherer.util.Utility;


public class MetadataValueTableCellRenderer
    extends DefaultTableCellRenderer
{
    private MetadataValueTableModel metadata_value_table_model = null;


    public MetadataValueTableCellRenderer(MetadataValueTableModel metadata_value_table_model)
    {
	super();
	this.metadata_value_table_model = metadata_value_table_model;
    }


    /** Returns the default table cell renderer.
     * @param table The <strong>JTable</strong>.
     * @param value The value to assign to the cell at [row, column] as an <strong>Object</strong>.
     * @param isSelected <i>true</i> if cell is selected.
     * @param hasFocus <i>true</i> if cell has focus.
     * @param row The row of the cell to render as an <i>int</i>.
     * @param column The column of the cell to render as an <i>int</i>.
     * @return The default table cell renderer <strong>Component</strong>.
     */
    public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int column)
    {
	JLabel renderer = null;

	// First column: inherited metadata icon
	if (column == 0 && value != null) {
	    renderer = new JLabel(Utility.getImage("upfolder.gif"));
	}
	else {
	    renderer = (JLabel) super.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, column);
	}

	// Set up the component
	renderer.setOpaque(true);

	// Foreground
	if (metadata_value_table_model.isCommon(row)) {
	    renderer.setForeground(Color.black);
	}
	else {
	    renderer.setForeground(Color.gray);
	}

	// Background
	if (isSelected) {
	    renderer.setBackground(Configuration.getColor("coloring.workspace_heading_background", true));
	}
	else {
	    if (column <= 1) {
		renderer.setBackground(Configuration.getColor("coloring.collection_heading_background", true));
	    }
	    else {
		renderer.setBackground(Configuration.getColor("coloring.collection_tree_background", true));
	    }
	}

	// Finally the 3rd column of cells never paint focus.
	if (column == 2) {
	    renderer.setBorder(BorderFactory.createEmptyBorder(0,0,0,0));
	}

	// We set a tooltip over the element column containing the definition of the element
	if (value instanceof MetadataElement) {
	    String interface_language_code = Configuration.getLanguage();
	    String metadata_element_definition = MetadataTools.getMetadataElementAttribute((MetadataElement) value, "definition", interface_language_code, "en");
	    if (metadata_element_definition != null) {
		renderer.setToolTipText(Utility.formatHTMLWidth(metadata_element_definition, 60));
	    }
	}

	return renderer;
    }
}
